@@ -21,4 +21,8 @@ class AWSSQSHandler:
             QueueUrl=queue_url,
             MessageBody=json.dumps(data),
             **kwargs
-        )
\ No newline at end of file
+        )
+    
+    def delete_message(self, queue_url, receipt_handle, **kwargs):
+        return self.client.delete_message(
+            QueueUrl=queue_url, ReceiptHandle=receipt_handle)
\ No newline at end of file
